@@ -1,12 +1,27 @@
+#   Copyright © 2020 Sidemash Cloud Services
+#
+#   Licensed under the Apache  License, Version 2.0 (the "License");
+#   you may not use this file except in compliance with the License.
+#   You may obtain a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#   Unless  required  by  applicable  law  or  agreed to in writing,
+#   software  distributed  under  the  License  is distributed on an
+#   "AS IS"  BASIS, WITHOUT  WARRANTIES  OR CONDITIONS OF  ANY KIND,
+#   either  express  or  implied.  See the License for the  specific
+#   language governing permissions and limitations under the License.
+
+
 from typing import Dict
 import json
 
 
 class Auth:
-    def __init__(self, token: str, private_key: str):
+    def __init__(self, token: str, secret_key: str):
         self._type = "Auth" 
         self.token = token
-        self.private_key = private_key
+        self.secret_key = secret_key
 
     @staticmethod
     def _type(): 
@@ -20,25 +35,25 @@ class Auth:
     def __to_remote_dict(self):
         tuples = [
             ('token', self.token),
-            ('privateKey', self.private_key)
+            ('secretKey', self.secret_key)
         ]
         return dict(t for t in tuples if t[1] is not None)
 
     def to_dict(self):
         return dict([
             ('token', self.token),
-            ('private_key', self.private_key)
+            ('secret_key', self.secret_key)
         ])
 
     @staticmethod
     def __from_remote_dict(d: Dict[str, any]):
         return Auth(d["token"],
-                    d["privateKey"])
+                    d["secretKey"])
 
     @staticmethod
     def from_dict(d: Dict[str, any]):
         return Auth(d["token"],
-                    d["private_key"])
+                    d["secret_key"])
 
     def to_json(self):
         return json.dumps(self.to_dict())
@@ -51,4 +66,4 @@ class Auth:
 
     def __repr__(self):
         return ("Auth(token=" + self.token + 
-                     ", private_key=******" + ")")
\ No newline at end of file
+                     ", secret_key=******" + ")")
\ No newline at end of file
